pub fn look_at_quat(eye: DVec3, center: DVec3, up: DVec3) -> DQuatExpand description
Returns a DQuat view rotation from eye, focal point, and up.
Transforms right-handed world space points into right-handed Y-up view space.
Panics
Will panic if up is not normalized when glam_assert is enabled.